@@ -33,6 +33,7 @@ def main():
     try:
         _run(*decompress(data_loaded))
     except TypeError as e:
+        raise (e)
         print("Please double-check your project parameters.yaml document'")
         log.exception(e)
         os.startfile(os.path.join(os.getcwd(), "project parameters.yaml"))
@@ -65,44 +66,18 @@ def _run(method_listing, temperature_listing, root, wavelengths, rms):
 
     all_frames = aithermal.load_dsc(method_listing, baseline_path, rms, wavelengths)
 
-    tracer = {}
+    tracer = []
     for method, data in all_frames.items():
-        tracer[method] = aithermal.write_topic_structured_csv(data, method, root)
-    acd_frame = []
-    ms_frame = []
-    for method, trace in tracer.items():
-        if method == "MS":
-            z = pd.DataFrame.from_dict(trace, orient="index").stack()
-            r = (
-                z.reset_index()
-                .set_index("level_0")
-                .drop(columns="level_1", errors="ignore")
-                .rename(columns={0: "MS File"})
-            )
-            ms_frame = r
-        else:
-            acd_frame.append(generate_results_csv_acd(trace, f"{method} File"))
-
-    tracers = pd.concat(acd_frame, axis=1)
-    tracers = ms_frame.join(tracers)
-
-    tracers["Gradient"] = ",".join([str(x) for x in gradient_temp])
-    tracers["Isotherms"] = ",".join([str(x) for x in isotherm_temp])
-    tracers = tracers.reset_index()
-    tracers = tracers.rename(columns={"index": "Name"})
-    tracers.to_csv(os.path.join(root, "ACD Trace.csv"), index=False, sep=";")
-
-    acd_frame.append(ms_frame)
-    for this_frame in acd_frame:
-        this_frame["Gradient"] = ",".join([str(x) for x in gradient_temp])
-        this_frame["Isotherms"] = ",".join([str(x) for x in isotherm_temp])
-        this_frame = this_frame.reset_index()
-        this_frame = this_frame.rename(columns={"index": "Name", "level_0": "Name"})
-        method = this_frame.columns[1].split(" ")[0]
-        this_frame["Method"] = method
-        this_frame.to_csv(
-            os.path.join(root, f"{method} Trace.csv"), index=False, sep=";"
+        tracer.extend(
+            aithermal.write_topic_structured_csv(data, method, root, wavelengths)
         )
+    df = pd.concat(tracer, axis=0, ignore_index=True)
+    acd_trace_path = os.path.join(root, "ACD Traces")
+    try:
+        os.mkdir(acd_trace_path)
+    except OSError:
+        pass
+    df.to_csv(os.path.join(acd_trace_path, "ACD Trace.csv"), index=False, sep=";")
 
 
 def generate_results_csv_acd(frame, prefix):
